@@ -5,23 +5,28 @@ from pathlib import Path
 from typing import Any, Dict, Iterable, List, Union
 
 from tabml.feature_manager import BaseFeatureManager
-from tabml.model_wrappers import initialize_model_wrapper_from_full_pipeline_pickle
-from tabml.utils.utils import load_pickle
+from tabml.model_wrappers import initialize_model_wrapper
+from tabml.utils.utils import return_or_load, load_pickle
+from tabml.schemas.bundles import PipelineBundle
 
 
 @dataclass
 class ModelInference:
     feature_manager_cls: BaseFeatureManager
-    full_pipeline_path: Union[str, Path]
+    pipeline_bundle: Union[str, Path, PipelineBundle]
 
     def __post_init__(self):
         # Load pickle
-        data = load_pickle(self.full_pipeline_path)
+        _pipeline_bundle: PipelineBundle = return_or_load(
+            self.pipeline_bundle, PipelineBundle, load_pickle
+        )
         # Initialize feature_manager
-        self.fm = self.feature_manager_cls.from_full_pipeline_data(data)
+        self.fm = self.feature_manager_cls.from_feature_bundle(
+            _pipeline_bundle.feature_bundle
+        )
         # Initialize model_wrapper
-        pipeline_config = data["pipeline_config"]
-        self.model_wrapper = initialize_model_wrapper_from_full_pipeline_pickle(data)
+        pipeline_config = _pipeline_bundle.model_bundle.pipeline_config
+        self.model_wrapper = initialize_model_wrapper(_pipeline_bundle.model_bundle)
         self.features_to_model = list(pipeline_config.data_loader.features_to_model)
 
     def predict(self, raw_data: List[Dict[str, Any]]) -> Iterable[Any]:
