@@ -11,9 +11,10 @@ from tabml.data_loaders import BaseDataLoader
 from tabml.feature_manager import BaseFeatureManager
 from tabml.model_analysis import ModelAnalysis
 from tabml.schemas.pipeline_config import PipelineConfig
+from tabml.schemas.bundles import PipelineBundle, ModelBundle
 from tabml.utils import factory
 from tabml.utils.logger import logger
-from tabml.utils.utils import load_pickle
+from tabml.utils.utils import load_pickle, return_or_load
 
 
 class BasePipeline(ABC):
@@ -21,34 +22,33 @@ class BasePipeline(ABC):
 
     Attributions:
         config:
-            A pipeline config object.
+            A pipeline config object or a path to config. If path, then parse the
+            pipeline config.
         data_loader:
             A data loader object, a subclass of base.data_loaders.BaseDataLoader.
         exp_manager:
             A base.experiment_manager.ExperimentManager object.
     """
 
-    def __init__(self, config: PipelineConfig, custom_run_dir: str = ""):
-        self.config = config
+    def __init__(
+        self, config: Union[str, Path, PipelineConfig], custom_run_dir: str = ""
+    ):
+        self.config = return_or_load(config, PipelineConfig, parse_pipeline_config)
         logger.info("=" * 80)
         logger.info(f"Running pipeline with config name {self.config.config_name}")
         logger.info("=" * 80)
+        _custom_run_dir = Path(custom_run_dir) if custom_run_dir else None
         self.exp_manager = experiment_manager.ExperimentManager(
-            config, custom_run_dir=Path(custom_run_dir)
+            self.config, custom_run_dir=_custom_run_dir
         )
         self.data_loader = self._get_data_loader()
         assert self.data_loader.label_col is not None, "label_col must be specified"
         self.model_wrapper = model_wrappers.initialize_model_wrapper(
-            self.config.model_wrapper
+            ModelBundle(pipeline_config=self.config, model=None),
         )
 
         logger.add(self.exp_manager.get_log_path())
 
-    @classmethod
-    def from_config_path(cls, config_path: Union[str, Path], custom_run_dir: str = ""):
-        config = parse_pipeline_config(config_path)
-        return cls(config, custom_run_dir)
-
     def run(self):
         self.exp_manager.create_new_run_dir()
         self._init_mlflow()
@@ -56,21 +56,22 @@ class BasePipeline(ABC):
             self._log_to_mlflow()
             self.train()
             self.analyze_model()
-        self.save_full_pipeline_pickle()
+        self.save_pipeline_bundle()
 
-    def save_full_pipeline_pickle(self):
-        feature_config_and_transformer_path = BaseFeatureManager(
+    def save_pipeline_bundle(self):
+        feature_bundle_path = BaseFeatureManager(
             self.config.data_loader.feature_config_path
-        ).get_config_and_transformer_path()
-        feature_data = load_pickle(feature_config_and_transformer_path)
-        data = {
-            "feature_config": feature_data["feature_config"],
-            "transformers": feature_data["transformers"],
-            "pipeline_config": self.config,
-            "model": self.model_wrapper.model,
-        }
-        save_path = self.exp_manager.get_full_pipeline_path()
-        logger.info(f"Saving full pipeline to {save_path}")
+        ).get_feature_bundle_path()
+        feature_bundle = load_pickle(feature_bundle_path)
+        data = PipelineBundle(
+            feature_bundle=feature_bundle,
+            model_bundle=ModelBundle(
+                pipeline_config=self.config,
+                model=self.model_wrapper.model,
+            ),
+        )
+        save_path = self.exp_manager.get_pipeline_bundle_path()
+        logger.info(f"Saving pipeline bundle to {save_path}")
         with open(save_path, "wb") as pickle_file:
             pickle.dump(data, pickle_file)
 
